/** \file common.h
  * \brief Common header files required by all other modules
  * <PRE> Author: Anand Patwardhan
  * email: anand.patwardhan@umbc.edu
  * Date : 30 April 2004
  *
  *****************************************************************************
  * The SNOOP program is an intrusion detection mechanism to detect local
  * intrusions in a Mobile Ad Hoc Network.
  *
  *  Copyright(C) 2005 University of Maryland, Baltimore County (UMBC)
  *  E-mail: anand.patwardhan@umbc.edu
  *
  *  eBiquity Research Group
  *  University of Maryland, Baltimore County
  *  1000 Hilltop Circle, Baltimore, MD 21250, USA.
  *
  *  http://research.ebiquity.org
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
  *  of the License, or (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *******************************************************************************
  *  </PRE>
  */

#include <pcap.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <netinet/if_ether.h> 
#include <net/ethernet.h>
#include <netinet/ether.h> 
#include <netinet/ip.h> 
#include <netinet/ip6.h> 
#include <netinet/udp.h> 
#include <netinet/tcp.h>
#include <time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <signal.h>
#include <unistd.h>

#include "aodv.h"

/* These are 1, 2, 3, 4 resp. for IPv4 */
/*#define AODV6_RREQ	16
#define AODV6_RREP	17
#define AODV6_RERR	18
#define AODV6_RREP_ACK	19*/

//! The AODV6 message type values, from RFC 3561
/*! One of the RFC has values 16, 17, 18, 19 and one has 1, 2, 3, and 4
 */
#define AODV6_RREQ	1
#define AODV6_RREP	2
#define AODV6_RERR	3
#define AODV6_RREP_ACK	4

/* tcpdump header (ether.h) defines ETHER_HDRLEN) */
#ifndef ETHER_HDRLEN 
//! Length of the ethernet header in bytes
/*! This is usually already defined in ether.h
 */
#define ETHER_HDRLEN 14
#endif

#ifndef ETHERTYPE_IPV6
//! The protocol field value for IPv6
/*! The protocol field value for IPv6 over ethernet is 0x86dd
*/
#define ETHERTYPE_IPV6		0x86dd
#endif

#ifndef INET6
#define INET6 _INET_6_
#endif

//! Value for protocol field for TCP in IPv6 datagrams is 6
#define IP_PROTO_TCP 6

//! Value for protocol field for UDP in IPv6 datagrams is 17
#define IP_PROTO_UDP 17

//! Value for protocol field for ICMPv6 in IPv6 datagrams is 58
#define IP_PROTO_ICMPV6 58

